@@ -1,14 +1,19 @@
 """
 The Monitor connects to sources, evaluates rules, sends the resulting metrics to the stores.
 """
+from __future__ import annotations
+
 from collections.abc import Iterable
+from typing import get_type_hints
 from uuid import uuid4
 
 from sinai.exceptions import SourceNotFound
 from sinai.metrics import Metric
 from sinai.rules import Rule
+from sinai.sources import MetricSource
 from sinai.types import (
     Evaluation,
+    JDict,
     OptionalSourceInstances,
     RuleClass,
     RuleClasses,
@@ -34,6 +39,7 @@ class Monitor:
         self.stores: StoreClassList = []
         self._store_instances: StoreDict = {}
         self._source_instances: SourceDict = {}
+        self._source_map = {}  # type: ignore
         self._resolve_rules()
 
     def _add_source(self, source_cls: SourceClass) -> None:
@@ -44,12 +50,39 @@ class Monitor:
         if store_cls not in self.stores:
             self.stores.append(store_cls)
 
-    def _resolve_rules(self) -> None:
-        for rule in self.rules:
-            for source_cls in rule.sources:
+    def __resolve_stores_from_attribute(self, rule_cls) -> None:
+        """Get the stores from stores = []"""
+        for store_cls in rule_cls.stores:
+            self._add_store(store_cls)
+
+    def __resolve_sources_from_attribute(self, rule_cls) -> None:
+        """Get the sources from sources = []"""
+        for source_cls in rule_cls.sources:
+            self._add_source(source_cls)
+
+    def __resolve_sources_from_init(self, rule_cls) -> None:
+        self._source_map[rule_cls] = {}
+        try:
+            annos = get_type_hints(rule_cls.__init__, include_extras=True)
+        except NameError:
+            annos = rule_cls.__init__.__annotations__
+        for arg, source_cls in annos.items():
+            if arg == "monitor":
+                self._source_map[rule_cls]["monitor"] = self.__class__
+            elif arg == "return":
+                continue
+            elif source_cls == "MetricSource":
+                self._add_source(MetricSource)
+                self._source_map[rule_cls][arg] = MetricSource
+            else:
                 self._add_source(source_cls)
-            for store_cls in rule.stores:
-                self._add_store(store_cls)
+                self._source_map[rule_cls][arg] = source_cls
+
+    def _resolve_rules(self) -> None:
+        for rule_cls in self.rules:
+            self.__resolve_stores_from_attribute(rule_cls)
+            self.__resolve_sources_from_attribute(rule_cls)
+            self.__resolve_sources_from_init(rule_cls)
 
     def _connect_sources(self) -> None:
         for source_class in self.sources:
@@ -66,10 +99,22 @@ class Monitor:
     def _get_rule_sources(self, rule_cls: RuleClass) -> OptionalSourceInstances:
         return [self.source(source) for source in rule_cls.sources]
 
+    def _get_rule_args(self, rule_cls: RuleClass):
+        kwargs: JDict = {}
+        for arg, source_cls in self._source_map[rule_cls].items():
+            if arg == "monitor":
+                kwargs["monitor"] = self
+            else:
+                kwargs[arg] = self.source(source_cls)
+
+        return kwargs
+
     def _evaluate_rule(self, rule_class: RuleClass) -> None:
-        rule = rule_class(self)
-        rule_sources = self._get_rule_sources(rule_class)
-        result: Evaluation = rule.evaluate(*rule_sources)  # type: ignore
+        kwargs = self._get_rule_args(rule_class)
+        rule = rule_class(**kwargs)
+        if "monitor" not in kwargs:
+            rule.monitor = self
+        result: Evaluation = rule.evaluate()
         if isinstance(result, Iterable):
             for metric in result:
                 self.store_metric(rule, metric)
